@@ -1,5 +1,5 @@
 package Bot::Backbone::Service::Role::BareMetalChat;
-$Bot::Backbone::Service::Role::BareMetalChat::VERSION = '0.142820';
+$Bot::Backbone::Service::Role::BareMetalChat::VERSION = '0.160630';
 use v5.10;
 use Moose::Role;
 
@@ -44,11 +44,16 @@ Bot::Backbone::Service::Role::BareMetalChat - A chat service that is bolted on t
 
 =head1 VERSION
 
-version 0.142820
+version 0.160630
 
 =head1 DESCRIPTION
 
-This role is nearly identical to L<Bot::Backbone::Service::Role::Chat>, but is used to mark a chat service as one that will perform the final sending of a message to an external service (e.g., L<Bot::Backbone::Service::JabberChat> or L<Bot::Backbone::Service::ConsoleChat>) rather than one that just does some internal routing (e.g., L<Bot::Backbone::Service::GroupChat> or L<Bot::Backbone::Service::DirectChat>).
+This role is nearly identical to L<Bot::Backbone::Service::Role::Chat>, but is
+used to mark a chat service as one that will perform the final sending of a
+message to an external service (e.g., L<Bot::Backbone::Service::JabberChat> or
+L<Bot::Backbone::Service::ConsoleChat>) rather than one that just does some
+internal routing (e.g., L<Bot::Backbone::Service::GroupChat> or
+L<Bot::Backbone::Service::DirectChat>).
 
 =head1 AUTHOR
 
@@ -56,7 +61,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Qubling Software LLC.
+This software is copyright (c) 2016 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
